==> qtjambi-activex-6.3.3-sources.jar: io/qt/activex/QAxScriptManager.java <==
package io.qt.activex;


/**
 * <p>Bridge between application objects and script code</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qaxscriptmanager.html">QAxScriptManager</a></p>
 */
public class QAxScriptManager extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private java.util.Collection<Object> __rcObjects;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxScriptManager.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#error">QAxScriptManager::error(QAxScript*,int,QString,int,QString)</a></p>
     */
    public final Signal5<io.qt.activex.QAxScript, @io.qt.QtPrimitiveType Integer, java.lang.String, @io.qt.QtPrimitiveType Integer, java.lang.String> error = new Signal5<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAxScriptManager(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAxScriptManager() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#QAxScriptManager">QAxScriptManager::QAxScriptManager(QObject*)</a></p>
     */
    public QAxScriptManager(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAxScriptManager instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#addObject">QAxScriptManager::addObject(QAxBase*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addObject(io.qt.activex.QAxBase object){
        addObject_native_QAxBase_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object));
        if (object != null) {
            if(__rcObjects==null)
                __rcObjects = QtJambi_LibraryUtilities.internal.newRCList();
            __rcObjects.add(object);
        }
    }
    
    @io.qt.QtUninvokable
    private native void addObject_native_QAxBase_ptr(long __this__nativeId, long object);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#call-1">QAxScriptManager::call(QString,QList&lt;QVariant&gt;&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.util.Collection<? extends java.lang.Object> arguments){
        return call_native_cref_QString_ref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), function, arguments);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object call_native_cref_QString_ref_QList(long __this__nativeId, java.lang.String function, java.util.Collection<? extends java.lang.Object> arguments);
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}
     *  with <code>v8 = null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5, java.lang.Object v6, java.lang.Object v7) {
        return call(function, v1, v2, v3, v4, v5, v6, v7, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5, java.lang.Object v6) {
        return call(function, v1, v2, v3, v4, v5, v6, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5) {
        return call(function, v1, v2, v3, v4, v5, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4) {
        return call(function, v1, v2, v3, v4, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v4 = null</code></li>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3) {
        return call(function, v1, v2, v3, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v3 = null</code></li>
     * <li><code>v4 = null</code></li>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2) {
        return call(function, v1, v2, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v2 = null</code></li>
     * <li><code>v3 = null</code></li>
     * <li><code>v4 = null</code></li>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1) {
        return call(function, v1, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v1 = null</code></li>
     * <li><code>v2 = null</code></li>
     * <li><code>v3 = null</code></li>
     * <li><code>v4 = null</code></li>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function) {
        return call(function, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#call">QAxScriptManager::call(QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5, java.lang.Object v6, java.lang.Object v7, java.lang.Object v8){
        return call_native_cref_QString_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), function, v1, v2, v3, v4, v5, v6, v7, v8);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object call_native_cref_QString_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(long __this__nativeId, java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5, java.lang.Object v6, java.lang.Object v7, java.lang.Object v8);
    
    /**
     * <p>Overloaded function for {@link #functions(io.qt.activex.QAxScript.FunctionFlags)}
     *  with <code>arg__1 = io.qt.activex.QAxScript.FunctionFlags.FunctionNames</code>.</p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList functions() {
        return functions(io.qt.activex.QAxScript.FunctionFlags.FunctionNames);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#functions">QAxScriptManager::functions(QAxScript::FunctionFlags)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList functions(io.qt.activex.QAxScript.FunctionFlags arg__1){
        return functions_native_QAxScript_FunctionFlags_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1.value());
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList functions_native_QAxScript_FunctionFlags_constfct(long __this__nativeId, int arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#load">QAxScriptManager::load(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.activex.QAxScript load(java.lang.String code, java.lang.String name, java.lang.String language){
        return load_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), code, name, language);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.activex.QAxScript load_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String code, java.lang.String name, java.lang.String language);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#load-1">QAxScriptManager::load(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.activex.QAxScript load(java.lang.String file, java.lang.String name){
        return load_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), file, name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.activex.QAxScript load_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String file, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#script">QAxScriptManager::script(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.activex.QAxScript script(java.lang.String name){
        return script_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.activex.QAxScript script_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#scriptNames">QAxScriptManager::scriptNames()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList scriptNames(){
        return scriptNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList scriptNames_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #registerEngine(java.lang.String, java.lang.String, java.lang.String)}
     *  with <code>code = ""</code>.</p>
     */
    public static boolean registerEngine(java.lang.String name, java.lang.String extension) {
        return registerEngine(name, extension, "");
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#registerEngine">QAxScriptManager::registerEngine(QString,QString,QString)</a></p>
     */
    public native static boolean registerEngine(java.lang.String name, java.lang.String extension, java.lang.String code);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#scriptFileFilter">QAxScriptManager::scriptFileFilter()</a></p>
     */
    public native static java.lang.String scriptFileFilter();
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxScriptManager(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxScriptManager(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxScriptManager instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-activex-6.4.0-sources.jar: io/qt/activex/QAxScriptManager.java <==
package io.qt.activex;


/**
 * <p>Bridge between application objects and script code</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qaxscriptmanager.html">QAxScriptManager</a></p>
 */
public class QAxScriptManager extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private java.util.Collection<Object> __rcObjects;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxScriptManager.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#error">QAxScriptManager::error(QAxScript*,int,QString,int,QString)</a></p>
     */
    public final Signal5<io.qt.activex.QAxScript, @io.qt.QtPrimitiveType Integer, java.lang.String, @io.qt.QtPrimitiveType Integer, java.lang.String> error = new Signal5<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAxScriptManager(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QAxScriptManager() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#QAxScriptManager">QAxScriptManager::QAxScriptManager(QObject*)</a></p>
     */
    public QAxScriptManager(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAxScriptManager instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#addObject">QAxScriptManager::addObject(QAxBase*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addObject(io.qt.activex.QAxBase object){
        addObject_native_QAxBase_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object));
        if (object != null) {
            if(__rcObjects==null)
                __rcObjects = QtJambi_LibraryUtilities.internal.newRCList();
            __rcObjects.add(object);
        }
    }
    
    @io.qt.QtUninvokable
    private native void addObject_native_QAxBase_ptr(long __this__nativeId, long object);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#call-1">QAxScriptManager::call(QString,QList&lt;QVariant&gt;&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.util.Collection<? extends java.lang.Object> arguments){
        return call_native_cref_QString_ref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), function, arguments);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object call_native_cref_QString_ref_QList(long __this__nativeId, java.lang.String function, java.util.Collection<? extends java.lang.Object> arguments);
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}
     *  with <code>v8 = null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5, java.lang.Object v6, java.lang.Object v7) {
        return call(function, v1, v2, v3, v4, v5, v6, v7, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5, java.lang.Object v6) {
        return call(function, v1, v2, v3, v4, v5, v6, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5) {
        return call(function, v1, v2, v3, v4, v5, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4) {
        return call(function, v1, v2, v3, v4, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v4 = null</code></li>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3) {
        return call(function, v1, v2, v3, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v3 = null</code></li>
     * <li><code>v4 = null</code></li>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2) {
        return call(function, v1, v2, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v2 = null</code></li>
     * <li><code>v3 = null</code></li>
     * <li><code>v4 = null</code></li>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1) {
        return call(function, v1, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>Overloaded function for {@link #call(java.lang.String, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object, java.lang.Object)}</p>
     * <p>with: </p><ul>
     * <li><code>v1 = null</code></li>
     * <li><code>v2 = null</code></li>
     * <li><code>v3 = null</code></li>
     * <li><code>v4 = null</code></li>
     * <li><code>v5 = null</code></li>
     * <li><code>v6 = null</code></li>
     * <li><code>v7 = null</code></li>
     * <li><code>v8 = null</code></li>
     * </ul>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function) {
        return call(function, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null, (java.lang.Object)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#call">QAxScriptManager::call(QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object call(java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5, java.lang.Object v6, java.lang.Object v7, java.lang.Object v8){
        return call_native_cref_QString_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), function, v1, v2, v3, v4, v5, v6, v7, v8);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object call_native_cref_QString_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant_cref_QVariant(long __this__nativeId, java.lang.String function, java.lang.Object v1, java.lang.Object v2, java.lang.Object v3, java.lang.Object v4, java.lang.Object v5, java.lang.Object v6, java.lang.Object v7, java.lang.Object v8);
    
    /**
     * <p>Overloaded function for {@link #functions(io.qt.activex.QAxScript.FunctionFlags)}
     *  with <code>arg__1 = io.qt.activex.QAxScript.FunctionFlags.FunctionNames</code>.</p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList functions() {
        return functions(io.qt.activex.QAxScript.FunctionFlags.FunctionNames);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#functions">QAxScriptManager::functions(QAxScript::FunctionFlags)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList functions(io.qt.activex.QAxScript.FunctionFlags arg__1){
        return functions_native_QAxScript_FunctionFlags_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1.value());
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList functions_native_QAxScript_FunctionFlags_constfct(long __this__nativeId, int arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#load">QAxScriptManager::load(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.activex.QAxScript load(java.lang.String code, java.lang.String name, java.lang.String language){
        return load_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), code, name, language);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.activex.QAxScript load_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String code, java.lang.String name, java.lang.String language);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#load-1">QAxScriptManager::load(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.activex.QAxScript load(java.lang.String file, java.lang.String name){
        return load_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), file, name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.activex.QAxScript load_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String file, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#script">QAxScriptManager::script(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.activex.QAxScript script(java.lang.String name){
        return script_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.activex.QAxScript script_native_cref_QString_constfct(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#scriptNames">QAxScriptManager::scriptNames()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList scriptNames(){
        return scriptNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList scriptNames_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #registerEngine(java.lang.String, java.lang.String, java.lang.String)}
     *  with <code>code = (String)null</code>.</p>
     */
    public static boolean registerEngine(java.lang.String name, java.lang.String extension) {
        return registerEngine(name, extension, (String)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#registerEngine">QAxScriptManager::registerEngine(QString,QString,QString)</a></p>
     */
    public native static boolean registerEngine(java.lang.String name, java.lang.String extension, java.lang.String code);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxscriptmanager.html#scriptFileFilter">QAxScriptManager::scriptFileFilter()</a></p>
     */
    public native static java.lang.String scriptFileFilter();
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxScriptManager(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxScriptManager(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxScriptManager instance, QDeclarativeConstructor constructor);
    
}
